@@ -39,13 +39,14 @@ class CBase:
     VOLTAGE_COR = None  # Define in subclass
     # MAX_MEMORY = 2**29 = 536 MS (or better 512 MS)
 
-    def __init__(self, name: str, sampling: float) -> None:
+    def __init__(self, name: str, sampling: float, resolution: Any) -> None:
         """Inits CPicoscope"""
 
         self.status: dict = {}
         self.chandle = ctypes.c_int16()
         self.name = name
         self.sampling = sampling
+        self.resolution = resolution
 
         self.clib_path = self.find_clib()
 
@@ -151,9 +152,10 @@ class CBase:
             self._assert_pico_ok(self.status["openunit"])
 
         except errors.PicoSDKCtypesError as typerr:
-
             if self.PICO_STATUS_LOOKUP[self.status["openunit"]] == "PICO_NOT_FOUND":
-                raise Exception(f"Pico {self.name} not connected") from typerr
+                raise errors.DeviceNotFoundError(
+                    f"Pico {self.name} not connected"
+                ) from typerr
 
             powerstate = self.status["openunit"]
 
@@ -163,7 +165,7 @@ class CBase:
             elif powerstate == 286:  # PICO_USB3_0_DEVICE_NON_USB3_0_PORT
                 self.status["ChangePowerSource"] = self._change_power_source(286)
             else:
-                raise Exception(
+                raise errors.PicoError(
                     "[DEV] Status from openUnit not implemented"
                 ) from typerr
 
@@ -539,7 +541,7 @@ class C3000a(CBase):
             return int(math.log2(self.sampling * 1000000000))
         if (self.sampling * 1e9) % 8 == 0:
             return int(self.sampling * 125000000 + 2)
-        raise Exception("Sampling should be %8[ns]")
+        raise errors.InvalidTimebaseError("Sampling should be 1, 2, 4, %8[ns]")
 
     def run_block(self, pre_trig, post_trig, timebase, *args):
         """
@@ -645,33 +647,32 @@ class C5000a(CBase):
 
     @property
     def timebase(self):
-        resolution = 8
-        if resolution == 8:
+        if self.resolution == 8:
             if self.sampling in [1e-9, 2e-9, 4e-9]:
                 return int(math.log2(self.sampling * 1000000000))
             if (self.sampling * 1e9) % 8 == 0:
                 return int(self.sampling * 125000000 + 2)
-            raise Exception("Sampling should be %8[ns]")
-        if resolution == 12:
+            raise errors.InvalidTimebaseError("Sampling should be 1, 2, 4, %8[ns]")
+        if self.resolution == 12:
             if self.sampling in [2e-9, 4e-9, 8e-9]:
                 return int(math.log2(self.sampling * 1000000000))
             if (self.sampling * 1e9) % 16 == 0:
                 return int(self.sampling * 62500000 + 3)
-            raise Exception("Sampling should be %16[ns]")
+            raise errors.InvalidTimebaseError("Sampling should be 2, 4, 8, %16[ns]")
 
-        if resolution in [14, 15]:
+        if self.resolution in [14, 15]:
             if self.sampling in [8e-9]:
                 return 3
             if (self.sampling * 1e9) % 8 == 0:
                 return int(self.sampling * 125000000 + 2)
-            raise Exception("Sampling should be %8[ns]")
+            raise errors.InvalidTimebaseError("Sampling should be %8[ns]")
 
-        if resolution == 16:
+        if self.resolution == 16:
             if self.sampling in [16e-9]:
                 return 4
             if (self.sampling * 1e9) % 16 == 0:
                 return int(self.sampling * 62500000 + 3)
-            raise Exception("Sampling should be %8[ns]")
+            raise errors.InvalidTimebaseError("Sampling should be %16[ns]")
 
     def run_block(self, pre_trig, post_trig, timebase, *args):
         """
