@@ -20,7 +20,7 @@ class Picoscope(CPicoscope):
         self, name: str, sampling: float, duration: float, resolution=None
     ) -> None:
         # super(Picoscope, self).__init__(name=name)
-        super().__init__(name=name, sampling=sampling)
+        super().__init__(name=name, sampling=sampling, resolution=resolution)
         self.name = name
 
         mid_sample = int(duration / (2 * sampling))
